pub trait BcsHashable<'de>: Serialize + Deserialize<'de> { }Expand description
Activate the blanket implementation of Hashable based on serde and BCS.
- We use
serde_nameto extract a seed from the name of structs and enums. - We use
BCSto generate canonical bytes suitable for hashing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".